/**
 * Copyright (c) 2010 Perforce Software. All rights reserved.
 */
package com.perforce.maven.scm.provider.p4.command.add;

import java.util.ArrayList;
import java.util.List;

import org.apache.maven.scm.ScmFile;
import org.apache.maven.scm.ScmFileStatus;

import com.perforce.maven.scm.provider.p4.command.P4Result;
import com.perforce.p4java.core.file.IFileSpec;

/**
 * This class handles the result from the Perforce add command.
 */
public class P4AddResult
    extends P4Result
{

    /** The additions. */
    private List<ScmFile> additions = new ArrayList<ScmFile>();

    /**
     * @see com.perforce.maven.scm.provider.p4.command.P4Result#processMessage (java.lang.String)
     */
    @Override
    public String processMessage( String message )
    {
        return null;
    }

    /**
     * Extracts the file paths from the add command result filespecs.
     * 
     * @param fileSpecs the file specs
     */
    public void processAdditions( List<IFileSpec> fileSpecs )
    {
        if ( fileSpecs != null )
        {
            for ( IFileSpec fileSpec : fileSpecs )
            {
                if ( fileSpec != null )
                {
                    if ( fileSpec.getDepotPath() != null )
                    {
                        additions.add( new ScmFile( fileSpec.getDepotPath().getPathString(), ScmFileStatus.ADDED ) );
                    }
                }
            }
        }
    }

    /**
     * Gets the additions.
     * 
     * @return the additions
     */
    public List<ScmFile> getAdditions()
    {
        return additions;
    }
}
